@@ -1,6 +1,6 @@
 #!perl -w
 #
-# $Id: exe_wrap.pl,v 1.41 2004/04/13 22:20:55 epaepa Exp $
+# $Id: exe_wrap.pl,v 1.49 2004/09/27 21:10:52 epaepa Exp $
 # This is a quick XMLTV shell routing to use with the windows exe
 #
 # A single EXE is needed to allow sharing of modules and dlls of all the
@@ -38,6 +38,12 @@ END
     exit 1;
 }
 
+#
+# check for --quiet
+#
+my $opt_quiet=0;
+foreach (@ARGV) {$opt_quiet = 1 if /--quiet/i };
+
 #
 # get/check time zone
 #
@@ -54,13 +60,13 @@ unless (exists $ENV{TZ})
        $ENV{TZ}= $tz;
 
 } #timezone
-print STDERR "Timezone is $ENV{TZ}\n";
+print STDERR "Timezone is $ENV{TZ}\n" unless $opt_quiet;
 
 
 $cmd = shift || "";
 
 # --version (and abbreviations thereof)
-my $VERSION = '0.5.32';
+my $VERSION = '0.5.35';
 if (index('--version', $cmd) == 0 and length $cmd >= 3) {
     print "xmltv $VERSION\n";
     exit;
@@ -69,7 +75,7 @@ if (index('--version', $cmd) == 0 and length $cmd >= 3) {
 #
 # some grabbers aren't included
 #
-if ($cmd =~ /^tv_grab_(?:nz|jp|se)$/) {
+if ($cmd =~ /^tv_grab_(?:nz|jp)$/) {
     die <<END
 Sorry, $cmd is not available in this Windows binary release, although
 it is included in xmltv source releases.
@@ -82,8 +88,11 @@ END
 # some programs use a "share" directory
 #
 if ($cmd eq 'tv_grab_uk_rt'
+ or $cmd eq 'tv_grab_uk_bleb'
  or $cmd eq 'tv_grab_it'
  or $cmd eq 'tv_grab_nl'
+ or $cmd eq 'tv_grab_na_dd',
+ or $cmd eq 'tv_grab_na_icons',
  or $cmd eq 'tv_grab_de_tvtoday'
  )
 {
@@ -97,7 +106,7 @@ if ($cmd eq 'tv_grab_uk_rt'
     	    {
 	        die "directory $dir not found\n If not kept with the executable, specify with --share\n"
 	        }
-        print STDERR "adding '--share=$dir'\n";
+        print STDERR "adding '--share=$dir'\n" unless $opt_quiet;
         push @ARGV,"--share",$dir;
     }
 }
@@ -120,6 +129,7 @@ foreach my $exe (split(/ /,$files))
 #
     $0 = $_;        # set $0 to our script
     do $exe;
+    print STDERR $@ if length($@);
     exit 0;
 }
 
